package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.BasicInfo;

/**
 * 基本信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-12
 */
public interface BasicInfoMapper 
{
    /**
     * 查询基本信息
     * 
     * @param id 基本信息主键
     * @return 基本信息
     */
    public BasicInfo selectBasicInfoById(Long id);

    /**
     * 查询基本信息列表
     * 
     * @param basicInfo 基本信息
     * @return 基本信息集合
     */
    public List<BasicInfo> selectBasicInfoList(BasicInfo basicInfo);

    /**
     * 新增基本信息
     * 
     * @param basicInfo 基本信息
     * @return 结果
     */
    public int insertBasicInfo(BasicInfo basicInfo);

    /**
     * 修改基本信息
     * 
     * @param basicInfo 基本信息
     * @return 结果
     */
    public int updateBasicInfo(BasicInfo basicInfo);

    /**
     * 删除基本信息
     * 
     * @param id 基本信息主键
     * @return 结果
     */
    public int deleteBasicInfoById(Long id);

    /**
     * 批量删除基本信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicInfoByIds(Long[] ids);
}
