package com.ruoyi.web.controller.work;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BasicInfo;
import com.ruoyi.system.service.IBasicInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 基本信息Controller
 * 
 * @author ruoyi
 * @date 2025-05-12
 */
@RestController
@RequestMapping("/basic/info")
public class BasicInfoController extends BaseController
{
    @Autowired
    private IBasicInfoService basicInfoService;

    /**
     * 查询基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('basic:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(BasicInfo basicInfo)
    {
        startPage();
        List<BasicInfo> list = basicInfoService.selectBasicInfoList(basicInfo);
        return getDataTable(list);
    }

    /**
     * 导出基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('basic:info:export')")
    @Log(title = "基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicInfo basicInfo)
    {
        List<BasicInfo> list = basicInfoService.selectBasicInfoList(basicInfo);
        ExcelUtil<BasicInfo> util = new ExcelUtil<BasicInfo>(BasicInfo.class);
        util.exportExcel(response, list, "基本信息数据");
    }

    /**
     * 获取基本信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('basic:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(basicInfoService.selectBasicInfoById(id));
    }

    /**
     * 新增基本信息
     */
    @PreAuthorize("@ss.hasPermi('basic:info:add')")
    @Log(title = "基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BasicInfo basicInfo)
    {
        return toAjax(basicInfoService.insertBasicInfo(basicInfo));
    }

    /**
     * 修改基本信息
     */
    @PreAuthorize("@ss.hasPermi('basic:info:edit')")
    @Log(title = "基本信息", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody BasicInfo basicInfo)
    {
        return toAjax(basicInfoService.updateBasicInfo(basicInfo));
    }

    /**
     * 删除基本信息
     */
    @PreAuthorize("@ss.hasPermi('basic:info:remove')")
    @Log(title = "基本信息", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(basicInfoService.deleteBasicInfoByIds(ids));
    }
}
